# -*- coding: utf-8 -*-

__all__ = [
    'status_pb2', 'status_pb2_grpc',
    'milvus_pb2', 'milvus_pb2_grpc',
    'common_pb2', 'common_pb2_grpc',
    'schema_pb2', 'schema_pb2_grpc',
    'service_pb2', 'service_pb2_grpc',
    'service_msg_pb2', 'service_msg_pb2_grpc',
]
