# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service_msg.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import schema_pb2 as schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='service_msg.proto',
  package='milvus.proto.service',
  syntax='proto3',
  serialized_options=_b('ZAgithub.com/zilliztech/milvus-distributed/internal/proto/servicepb'),
  serialized_pb=_b('\n\x11service_msg.proto\x12\x14milvus.proto.service\x1a\x0c\x63ommon.proto\x1a\x0cschema.proto\")\n\x0e\x43ollectionName\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\"5\n\rPartitionName\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"z\n\x08RowBatch\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x15\n\rpartition_tag\x18\x02 \x01(\t\x12+\n\x08row_data\x18\x03 \x03(\x0b\x32\x19.milvus.proto.common.Blob\x12\x11\n\thash_keys\x18\x04 \x03(\r\"d\n\x10PlaceholderValue\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32%.milvus.proto.service.PlaceholderType\x12\x0e\n\x06values\x18\x03 \x03(\x0c\"P\n\x10PlaceholderGroup\x12<\n\x0cplaceholders\x18\x01 \x03(\x0b\x32&.milvus.proto.service.PlaceholderValue\"`\n\x05Query\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x16\n\x0epartition_tags\x18\x02 \x03(\t\x12\x0b\n\x03\x64sl\x18\x03 \x01(\t\x12\x19\n\x11placeholder_group\x18\x04 \x01(\x0c\"L\n\x0eStringResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\t\"J\n\x0c\x42oolResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05value\x18\x02 \x01(\x08\"Q\n\x12StringListResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0e\n\x06values\x18\x02 \x03(\t\"R\n\x13IntegerListResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0e\n\x06values\x18\x02 \x03(\x03\"_\n\x14IntegerRangeResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\r\n\x05\x62\x65gin\x18\x02 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x03\"\xb2\x01\n\x15\x43ollectionDescription\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x35\n\x06schema\x18\x02 \x01(\x0b\x32%.milvus.proto.schema.CollectionSchema\x12\x35\n\nstatistics\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"\xad\x01\n\x14PartitionDescription\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x31\n\x04name\x18\x02 \x01(\x0b\x32#.milvus.proto.service.PartitionName\x12\x35\n\nstatistics\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"^\n\x11SysConfigResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"5\n\x04Hits\x12\x0b\n\x03IDs\x18\x01 \x03(\x03\x12\x10\n\x08row_data\x18\x02 \x03(\x0c\x12\x0e\n\x06scores\x18\x03 \x03(\x02\"H\n\x0bQueryResult\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x0c\n\x04hits\x18\x02 \x03(\x0c\"r\n\nIndexParam\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\x12\x37\n\x0c\x65xtra_params\x18\x03 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair\"C\n\x14\x44\x65scribeIndexRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\"K\n\x1c\x44\x65scribeIndexProgressRequest\x12\x17\n\x0f\x63ollection_name\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\"\xaa\x01\n\x15\x44\x65scribeIndexResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.milvus.proto.common.Status\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\x12\x12\n\nfield_name\x18\x03 \x01(\t\x12\x37\n\x0c\x65xtra_params\x18\x04 \x03(\x0b\x32!.milvus.proto.common.KeyValuePair*@\n\x0fPlaceholderType\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rVECTOR_BINARY\x10\x64\x12\x10\n\x0cVECTOR_FLOAT\x10\x65\x42\x43ZAgithub.com/zilliztech/milvus-distributed/internal/proto/servicepbb\x06proto3')
  ,
  dependencies=[common__pb2.DESCRIPTOR,schema__pb2.DESCRIPTOR,])

_PLACEHOLDERTYPE = _descriptor.EnumDescriptor(
  name='PlaceholderType',
  full_name='milvus.proto.service.PlaceholderType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VECTOR_BINARY', index=1, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VECTOR_FLOAT', index=2, number=101,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2010,
  serialized_end=2074,
)
_sym_db.RegisterEnumDescriptor(_PLACEHOLDERTYPE)

PlaceholderType = enum_type_wrapper.EnumTypeWrapper(_PLACEHOLDERTYPE)
NONE = 0
VECTOR_BINARY = 100
VECTOR_FLOAT = 101



_COLLECTIONNAME = _descriptor.Descriptor(
  name='CollectionName',
  full_name='milvus.proto.service.CollectionName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.CollectionName.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=112,
)


_PARTITIONNAME = _descriptor.Descriptor(
  name='PartitionName',
  full_name='milvus.proto.service.PartitionName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.PartitionName.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='milvus.proto.service.PartitionName.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=167,
)


_ROWBATCH = _descriptor.Descriptor(
  name='RowBatch',
  full_name='milvus.proto.service.RowBatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.RowBatch.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_tag', full_name='milvus.proto.service.RowBatch.partition_tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_data', full_name='milvus.proto.service.RowBatch.row_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash_keys', full_name='milvus.proto.service.RowBatch.hash_keys', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=291,
)


_PLACEHOLDERVALUE = _descriptor.Descriptor(
  name='PlaceholderValue',
  full_name='milvus.proto.service.PlaceholderValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='milvus.proto.service.PlaceholderValue.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='milvus.proto.service.PlaceholderValue.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.service.PlaceholderValue.values', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=393,
)


_PLACEHOLDERGROUP = _descriptor.Descriptor(
  name='PlaceholderGroup',
  full_name='milvus.proto.service.PlaceholderGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placeholders', full_name='milvus.proto.service.PlaceholderGroup.placeholders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=395,
  serialized_end=475,
)


_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='milvus.proto.service.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.Query.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition_tags', full_name='milvus.proto.service.Query.partition_tags', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dsl', full_name='milvus.proto.service.Query.dsl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placeholder_group', full_name='milvus.proto.service.Query.placeholder_group', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=477,
  serialized_end=573,
)


_STRINGRESPONSE = _descriptor.Descriptor(
  name='StringResponse',
  full_name='milvus.proto.service.StringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.StringResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.service.StringResponse.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=651,
)


_BOOLRESPONSE = _descriptor.Descriptor(
  name='BoolResponse',
  full_name='milvus.proto.service.BoolResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.BoolResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='milvus.proto.service.BoolResponse.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=727,
)


_STRINGLISTRESPONSE = _descriptor.Descriptor(
  name='StringListResponse',
  full_name='milvus.proto.service.StringListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.StringListResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.service.StringListResponse.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=810,
)


_INTEGERLISTRESPONSE = _descriptor.Descriptor(
  name='IntegerListResponse',
  full_name='milvus.proto.service.IntegerListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.IntegerListResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.service.IntegerListResponse.values', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=894,
)


_INTEGERRANGERESPONSE = _descriptor.Descriptor(
  name='IntegerRangeResponse',
  full_name='milvus.proto.service.IntegerRangeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.IntegerRangeResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='begin', full_name='milvus.proto.service.IntegerRangeResponse.begin', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='milvus.proto.service.IntegerRangeResponse.end', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=991,
)


_COLLECTIONDESCRIPTION = _descriptor.Descriptor(
  name='CollectionDescription',
  full_name='milvus.proto.service.CollectionDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.CollectionDescription.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='milvus.proto.service.CollectionDescription.schema', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='milvus.proto.service.CollectionDescription.statistics', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1172,
)


_PARTITIONDESCRIPTION = _descriptor.Descriptor(
  name='PartitionDescription',
  full_name='milvus.proto.service.PartitionDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.PartitionDescription.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='milvus.proto.service.PartitionDescription.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statistics', full_name='milvus.proto.service.PartitionDescription.statistics', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1175,
  serialized_end=1348,
)


_SYSCONFIGRESPONSE = _descriptor.Descriptor(
  name='SysConfigResponse',
  full_name='milvus.proto.service.SysConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.SysConfigResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys', full_name='milvus.proto.service.SysConfigResponse.keys', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='milvus.proto.service.SysConfigResponse.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1350,
  serialized_end=1444,
)


_HITS = _descriptor.Descriptor(
  name='Hits',
  full_name='milvus.proto.service.Hits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='IDs', full_name='milvus.proto.service.Hits.IDs', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_data', full_name='milvus.proto.service.Hits.row_data', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scores', full_name='milvus.proto.service.Hits.scores', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1499,
)


_QUERYRESULT = _descriptor.Descriptor(
  name='QueryResult',
  full_name='milvus.proto.service.QueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.QueryResult.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hits', full_name='milvus.proto.service.QueryResult.hits', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1573,
)


_INDEXPARAM = _descriptor.Descriptor(
  name='IndexParam',
  full_name='milvus.proto.service.IndexParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.IndexParam.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.service.IndexParam.field_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_params', full_name='milvus.proto.service.IndexParam.extra_params', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1575,
  serialized_end=1689,
)


_DESCRIBEINDEXREQUEST = _descriptor.Descriptor(
  name='DescribeIndexRequest',
  full_name='milvus.proto.service.DescribeIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.DescribeIndexRequest.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.service.DescribeIndexRequest.field_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1691,
  serialized_end=1758,
)


_DESCRIBEINDEXPROGRESSREQUEST = _descriptor.Descriptor(
  name='DescribeIndexProgressRequest',
  full_name='milvus.proto.service.DescribeIndexProgressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.DescribeIndexProgressRequest.collection_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.service.DescribeIndexProgressRequest.field_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1760,
  serialized_end=1835,
)


_DESCRIBEINDEXRESPONSE = _descriptor.Descriptor(
  name='DescribeIndexResponse',
  full_name='milvus.proto.service.DescribeIndexResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='milvus.proto.service.DescribeIndexResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_name', full_name='milvus.proto.service.DescribeIndexResponse.collection_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='milvus.proto.service.DescribeIndexResponse.field_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_params', full_name='milvus.proto.service.DescribeIndexResponse.extra_params', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1838,
  serialized_end=2008,
)

_ROWBATCH.fields_by_name['row_data'].message_type = common__pb2._BLOB
_PLACEHOLDERVALUE.fields_by_name['type'].enum_type = _PLACEHOLDERTYPE
_PLACEHOLDERGROUP.fields_by_name['placeholders'].message_type = _PLACEHOLDERVALUE
_STRINGRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_BOOLRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_STRINGLISTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_INTEGERLISTRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_INTEGERRANGERESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_COLLECTIONDESCRIPTION.fields_by_name['status'].message_type = common__pb2._STATUS
_COLLECTIONDESCRIPTION.fields_by_name['schema'].message_type = schema__pb2._COLLECTIONSCHEMA
_COLLECTIONDESCRIPTION.fields_by_name['statistics'].message_type = common__pb2._KEYVALUEPAIR
_PARTITIONDESCRIPTION.fields_by_name['status'].message_type = common__pb2._STATUS
_PARTITIONDESCRIPTION.fields_by_name['name'].message_type = _PARTITIONNAME
_PARTITIONDESCRIPTION.fields_by_name['statistics'].message_type = common__pb2._KEYVALUEPAIR
_SYSCONFIGRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_QUERYRESULT.fields_by_name['status'].message_type = common__pb2._STATUS
_INDEXPARAM.fields_by_name['extra_params'].message_type = common__pb2._KEYVALUEPAIR
_DESCRIBEINDEXRESPONSE.fields_by_name['status'].message_type = common__pb2._STATUS
_DESCRIBEINDEXRESPONSE.fields_by_name['extra_params'].message_type = common__pb2._KEYVALUEPAIR
DESCRIPTOR.message_types_by_name['CollectionName'] = _COLLECTIONNAME
DESCRIPTOR.message_types_by_name['PartitionName'] = _PARTITIONNAME
DESCRIPTOR.message_types_by_name['RowBatch'] = _ROWBATCH
DESCRIPTOR.message_types_by_name['PlaceholderValue'] = _PLACEHOLDERVALUE
DESCRIPTOR.message_types_by_name['PlaceholderGroup'] = _PLACEHOLDERGROUP
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
DESCRIPTOR.message_types_by_name['StringResponse'] = _STRINGRESPONSE
DESCRIPTOR.message_types_by_name['BoolResponse'] = _BOOLRESPONSE
DESCRIPTOR.message_types_by_name['StringListResponse'] = _STRINGLISTRESPONSE
DESCRIPTOR.message_types_by_name['IntegerListResponse'] = _INTEGERLISTRESPONSE
DESCRIPTOR.message_types_by_name['IntegerRangeResponse'] = _INTEGERRANGERESPONSE
DESCRIPTOR.message_types_by_name['CollectionDescription'] = _COLLECTIONDESCRIPTION
DESCRIPTOR.message_types_by_name['PartitionDescription'] = _PARTITIONDESCRIPTION
DESCRIPTOR.message_types_by_name['SysConfigResponse'] = _SYSCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['Hits'] = _HITS
DESCRIPTOR.message_types_by_name['QueryResult'] = _QUERYRESULT
DESCRIPTOR.message_types_by_name['IndexParam'] = _INDEXPARAM
DESCRIPTOR.message_types_by_name['DescribeIndexRequest'] = _DESCRIBEINDEXREQUEST
DESCRIPTOR.message_types_by_name['DescribeIndexProgressRequest'] = _DESCRIBEINDEXPROGRESSREQUEST
DESCRIPTOR.message_types_by_name['DescribeIndexResponse'] = _DESCRIBEINDEXRESPONSE
DESCRIPTOR.enum_types_by_name['PlaceholderType'] = _PLACEHOLDERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CollectionName = _reflection.GeneratedProtocolMessageType('CollectionName', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONNAME,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.CollectionName)
  })
_sym_db.RegisterMessage(CollectionName)

PartitionName = _reflection.GeneratedProtocolMessageType('PartitionName', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONNAME,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.PartitionName)
  })
_sym_db.RegisterMessage(PartitionName)

RowBatch = _reflection.GeneratedProtocolMessageType('RowBatch', (_message.Message,), {
  'DESCRIPTOR' : _ROWBATCH,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.RowBatch)
  })
_sym_db.RegisterMessage(RowBatch)

PlaceholderValue = _reflection.GeneratedProtocolMessageType('PlaceholderValue', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERVALUE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.PlaceholderValue)
  })
_sym_db.RegisterMessage(PlaceholderValue)

PlaceholderGroup = _reflection.GeneratedProtocolMessageType('PlaceholderGroup', (_message.Message,), {
  'DESCRIPTOR' : _PLACEHOLDERGROUP,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.PlaceholderGroup)
  })
_sym_db.RegisterMessage(PlaceholderGroup)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.Query)
  })
_sym_db.RegisterMessage(Query)

StringResponse = _reflection.GeneratedProtocolMessageType('StringResponse', (_message.Message,), {
  'DESCRIPTOR' : _STRINGRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.StringResponse)
  })
_sym_db.RegisterMessage(StringResponse)

BoolResponse = _reflection.GeneratedProtocolMessageType('BoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _BOOLRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.BoolResponse)
  })
_sym_db.RegisterMessage(BoolResponse)

StringListResponse = _reflection.GeneratedProtocolMessageType('StringListResponse', (_message.Message,), {
  'DESCRIPTOR' : _STRINGLISTRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.StringListResponse)
  })
_sym_db.RegisterMessage(StringListResponse)

IntegerListResponse = _reflection.GeneratedProtocolMessageType('IntegerListResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTEGERLISTRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.IntegerListResponse)
  })
_sym_db.RegisterMessage(IntegerListResponse)

IntegerRangeResponse = _reflection.GeneratedProtocolMessageType('IntegerRangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTEGERRANGERESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.IntegerRangeResponse)
  })
_sym_db.RegisterMessage(IntegerRangeResponse)

CollectionDescription = _reflection.GeneratedProtocolMessageType('CollectionDescription', (_message.Message,), {
  'DESCRIPTOR' : _COLLECTIONDESCRIPTION,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.CollectionDescription)
  })
_sym_db.RegisterMessage(CollectionDescription)

PartitionDescription = _reflection.GeneratedProtocolMessageType('PartitionDescription', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONDESCRIPTION,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.PartitionDescription)
  })
_sym_db.RegisterMessage(PartitionDescription)

SysConfigResponse = _reflection.GeneratedProtocolMessageType('SysConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYSCONFIGRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.SysConfigResponse)
  })
_sym_db.RegisterMessage(SysConfigResponse)

Hits = _reflection.GeneratedProtocolMessageType('Hits', (_message.Message,), {
  'DESCRIPTOR' : _HITS,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.Hits)
  })
_sym_db.RegisterMessage(Hits)

QueryResult = _reflection.GeneratedProtocolMessageType('QueryResult', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESULT,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.QueryResult)
  })
_sym_db.RegisterMessage(QueryResult)

IndexParam = _reflection.GeneratedProtocolMessageType('IndexParam', (_message.Message,), {
  'DESCRIPTOR' : _INDEXPARAM,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.IndexParam)
  })
_sym_db.RegisterMessage(IndexParam)

DescribeIndexRequest = _reflection.GeneratedProtocolMessageType('DescribeIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXREQUEST,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.DescribeIndexRequest)
  })
_sym_db.RegisterMessage(DescribeIndexRequest)

DescribeIndexProgressRequest = _reflection.GeneratedProtocolMessageType('DescribeIndexProgressRequest', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXPROGRESSREQUEST,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.DescribeIndexProgressRequest)
  })
_sym_db.RegisterMessage(DescribeIndexProgressRequest)

DescribeIndexResponse = _reflection.GeneratedProtocolMessageType('DescribeIndexResponse', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEINDEXRESPONSE,
  '__module__' : 'service_msg_pb2'
  # @@protoc_insertion_point(class_scope:milvus.proto.service.DescribeIndexResponse)
  })
_sym_db.RegisterMessage(DescribeIndexResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
